@@ -3,7 +3,6 @@ package dao
 import (
 	"context"
 	"errors"
-	"io/ioutil"
 	"os"
 	"regexp"
 
@@ -37,14 +36,16 @@ func (d *ScreenDump) List(ctx context.Context, _ string) ([]runtime.Object, erro
 		return nil, errors.New("no screendump dir found in context")
 	}
 
-	ff, err := ioutil.ReadDir(SanitizeFilename(dir))
+	ff, err := os.ReadDir(SanitizeFilename(dir))
 	if err != nil {
 		return nil, err
 	}
 
 	oo := make([]runtime.Object, len(ff))
 	for i, f := range ff {
-		oo[i] = render.FileRes{File: f, Dir: dir}
+		if fi, err := f.Info(); err == nil {
+			oo[i] = render.FileRes{File: fi, Dir: dir}
+		}
 	}
 
 	return oo, nil
