@@ -60,9 +60,10 @@ func miscViewers(vv MetaViewers) {
 	vv[client.NewGVR("contexts")] = MetaViewer{
 		viewerFn: NewContext,
 	}
-	vv[client.NewGVR("openfaas")] = MetaViewer{
-		viewerFn: NewOpenFaas,
-	}
+	// BOZO!! revamp with latest...
+	// vv[client.NewGVR("openfaas")] = MetaViewer{
+	// 	viewerFn: NewOpenFaas,
+	// }
 	vv[client.NewGVR("containers")] = MetaViewer{
 		viewerFn: NewContainer,
 	}
